#[non_exhaustive]pub enum Event {
TabletAdded {
id: ZwpTabletV2,
},
ToolAdded {
id: ZwpTabletToolV2,
},
PadAdded {
id: ZwpTabletPadV2,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
TabletAdded
new device notification
This event is sent whenever a new tablet becomes available on this seat. This event only provides the object id of the tablet, any static information about the tablet (device name, vid/pid, etc.) is sent through the zwp_tablet_v2 interface.
Fields
id: ZwpTabletV2the newly added graphics tablet
ToolAdded
a new tool has been used with a tablet
This event is sent whenever a tool that has not previously been used with a tablet comes into use. This event only provides the object id of the tool; any static information about the tool (capabilities, type, etc.) is sent through the zwp_tablet_tool_v2 interface.
Fields
id: ZwpTabletToolV2the newly added tablet tool
PadAdded
new pad notification
This event is sent whenever a new pad is known to the system. Typically, pads are physically attached to tablets and a pad_added event is sent immediately after the zwp_tablet_seat_v2.tablet_added. However, some standalone pad devices logically attach to tablets at runtime, and the client must wait for zwp_tablet_pad_v2.enter to know the tablet a pad is attached to.
This event only provides the object id of the pad. All further features (buttons, strips, rings) are sent through the zwp_tablet_pad_v2 interface.
Fields
id: ZwpTabletPadV2the newly added pad